=============
python-tomita
=============

.. image:: https://img.shields.io/pypi/v/tomita.svg
        :target: https://pypi.python.org/pypi/tomita

.. image:: https://img.shields.io/travis/python-g4brielvs/tomita.svg
        :target: https://travis-ci.com/g4brielvs/python-tomita

.. image:: https://pyup.io/repos/github/g4brielvs/python-tomita/shield.svg
     :target: https://pyup.io/repos/github/g4brielvs/python-tomita
     :alt: Updates

.. image:: https://readthedocs.org/projects/tomita/badge/?version=latest
        :target: https://tomita.readthedocs.io/en/latest/?badge=latest
        :alt: Documentation Status

.. image:: https://img.shields.io/pypi/l/Tomita.svg
        :target: https://pypi.python.org/pypi/tomita/
        :alt: License

*tomita* is a command-line music and synthesizer package.

* Free software: GNU General Public License v3
* Documentation: https://tomita.readthedocs.io.

About
-----

Isao Tomita (冨田 勲, Tomita Isao, 22 April 1932 – 5 May 2016), also known mononymically 
as Tomita, was a Japanese music-composer, regarded as one of the pioneers of electronic 
music and space music,and as one of the most famous producers of analog synthesizer 
arrangements. `Wikipedia <https://en.wikipedia.org/wiki/Isao_Tomita>`_


Features
--------

* TODO

PySynth
-------

All scripts from *PySynth* can the found as modules. 

To use *pysynth*:

.. code-block:: console

    $ python -m tomita.legacy.pysynth

To use *pysynth_b*:

.. code-block:: console

    $ python -m tomita.legacy.pysynth_b

To use *pysynth_c*:

.. code-block:: console

    $ python -m tomita.legacy.pysynth_c

and so on.

License
-------

`GNU General Public License v3.0 <https://choosealicense.com/licenses/gpl-3.0/>`_

